@@ -5,8 +5,8 @@ import PyPDF2
 import signer_pdf.sign_generator as sign_generator
 
 
-def sign(name, date, a_hash, in_file):
-    bs = sign_generator.convert(name, date, a_hash)
+def sign(name, date, a_hash, position, in_file):
+    bs = sign_generator.convert(name, date, a_hash, position)
     original = PyPDF2.PdfFileReader(in_file)
     last_page = original.getPage(original.getNumPages() - 1)
     foreground = PyPDF2.PdfFileReader(bs).getPage(0)
